@@ -18,6 +18,7 @@ package org.uberfire.java.nio.fs.jgit;
 
 import java.io.File;
 import java.io.IOException;
+import java.util.concurrent.TimeUnit;
 
 import org.assertj.core.api.AssertionsForClassTypes;
 import org.eclipse.jgit.api.errors.GitAPIException;
@@ -52,6 +53,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -77,6 +79,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -92,6 +95,12 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         assertThat(root.getRoot().toString()).isEqualTo("/");
     }
 
+    private JGitFileSystemLock createFSLock(Git git) {
+        return new JGitFileSystemLock(git,
+                                      TimeUnit.MILLISECONDS,
+                                      30_000L);
+    }
+
     @Test
     public void testProvider() throws IOException, GitAPIException {
         final JGitFileSystemProvider fsProvider = mock(JGitFileSystemProvider.class);
@@ -101,6 +110,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -121,6 +131,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -145,6 +156,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -168,6 +180,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -196,6 +209,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -224,6 +238,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -253,6 +268,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -282,6 +298,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -312,6 +329,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -341,6 +359,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -362,6 +381,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem1 = new JGitFileSystemImpl(fsProvider,
                                                                       null,
                                                                       git1,
+                                                                      createFSLock(git1),
                                                                       "my-repo1",
                                                                       CredentialsProvider.getDefault(),
                                                                       null);
@@ -371,6 +391,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem2 = new JGitFileSystemImpl(fsProvider,
                                                                       null,
                                                                       git2,
+                                                                      createFSLock(git2),
                                                                       "my-repo2",
                                                                       CredentialsProvider.getDefault(),
                                                                       null);
@@ -395,6 +416,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -410,6 +432,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -425,6 +448,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -440,6 +464,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
                                                                      null,
                                                                      git,
+                                                                     createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
                                                                      null);
@@ -457,9 +482,9 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
     public void lockTest() throws IOException, GitAPIException {
 
         final Git git = setupGit();
-        JGitFileSystemImpl.Lock lock = new JGitFileSystemImpl.Lock(git.getRepository().getDirectory().toURI());
+        JGitFileSystemLock lock = createFSLock(git);
 
-        JGitFileSystemImpl.Lock lockSpy = spy(lock);
+        JGitFileSystemLock lockSpy = spy(lock);
 
         lockSpy.lock();
         lockSpy.lock();
